# Generated by Django 2.0.13 on 2019-06-28 07:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0021_auto_20190627_1513")]

    operations = [
        migrations.AlterField(
            model_name="layer", name="view", field=models.IntegerField()
        )
    ]
