# Generated by Django 2.1.9 on 2019-07-23 08:14

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0032_auto_20190718_1742")]

    operations = [
        migrations.AddField(
            model_name="layergroup",
            name="settings",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        )
    ]
