# Generated by Django 3.0.4 on 2020-03-16 11:24

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("terra_layer", "0048_auto_20200227_1342"),
    ]

    operations = [
        migrations.AddField(
            model_name="filterfield",
            name="display",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="filterfield",
            name="settings",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="scene",
            name="config",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
