# Generated by Django 2.1.9 on 2019-07-18 14:01

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0030_layergroup_order")]

    operations = [
        migrations.AlterModelOptions(
            name="layergroup", options={"ordering": ["order"]}
        ),
        migrations.AlterField(
            model_name="layergroup",
            name="selectors",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                default=None, null=True
            ),
        ),
    ]
