# Generated by Django 2.0.13 on 2019-06-18 13:00

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0011_auto_20190612_1721")]

    operations = [
        migrations.AlterField(
            model_name="layer",
            name="source",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="layers",
                to="django_geosource.Source",
            ),
        )
    ]
